@@ -1,5 +1,6 @@
 # noinspection PyUnresolvedReferences
 from prompt_toolkit.validation import Validator, ValidationError
+from prompt_toolkit.styles import Style
 
 import questionary.version
 from questionary.form import Form
@@ -24,23 +25,27 @@ from questionary.prompts.rawselect import rawselect
 __version__ = questionary.version.__version__
 
 __all__ = [
-    "Validator",
-    "ValidationError",
-    "Form",
+    "__version__",
+    # question types
+    "autocomplete",
+    "checkbox",
+    "confirm",
+    "password",
+    "path",
+    "rawselect",
+    "select",
+    "text",
+    # utility methods
+    "print",
     "form",
     "prompt",
     "unsafe_prompt",
-    "Choice",
-    "Separator",
+    # commonly used classes
+    "Form",
     "Question",
-    "autocomplete",
-    "select",
-    "checkbox",
-    "text",
-    "confirm",
-    "password",
-    "print",
-    "path",
-    "rawselect",
-    "__version__",
+    "Choice",
+    "Style",
+    "Separator",
+    "Validator",
+    "ValidationError",
 ]
