@@ -7,7 +7,7 @@ from prompt_toolkit.styles import Style, merge_styles
 from prompt_toolkit.formatted_text import FormattedText
 
 from questionary import utils
-from questionary.constants import DEFAULT_QUESTION_PREFIX, DEFAULT_STYLE
+from questionary.constants import DEFAULT_QUESTION_PREFIX, DEFAULT_STYLE, INVALID_INPUT
 from questionary.prompts import common
 from questionary.prompts.common import Choice, InquirerControl, Separator
 from questionary.question import Question
@@ -17,7 +17,7 @@ def checkbox(
     message: str,
     choices: Sequence[Union[str, Choice, Dict[str, Any]]],
     default: Optional[str] = None,
-    validate: Callable[[List[str]], bool] = lambda a: True,
+    validate: Callable[[List[str]], Union[bool, str]] = lambda a: True,
     qmark: str = DEFAULT_QUESTION_PREFIX,
     style: Optional[Style] = None,
     use_pointer: bool = True,
@@ -29,27 +29,46 @@ def checkbox(
     This is a multiselect, the user can choose one, none or many of the
     items.
 
+    Example:
+        >>> import questionary
+        >>> questionary.checkbox(
+        ...    'Select toppings',
+        ...    choices=[
+        ...        "Cheese",
+        ...        "Tomato",
+        ...        "Pineapple",
+        ...    ]).ask()
+        ? Select toppings done (2 selections)
+        ['Cheese', 'Pineapple']
+
+    .. image:: ../images/checkbox.gif
+
+    This is just a realy basic example, the prompt can be customised using the
+    parameters.
+
+
     Args:
         message: Question text
 
-        choices: Items shown in the selection, this can contain `Choice` or
-                 or `Separator` objects or simple items as strings. Passing
-                 `Choice` objects, allows you to configure the item more
+        choices: Items shown in the selection, this can contain :class:`Choice` or
+                 or :class:`Separator` objects or simple items as strings. Passing
+                 :class:`Choice` objects, allows you to configure the item more
                  (e.g. preselecting it or disabling it).
 
         default: Default return value (single value). If you want to preselect
-                 multiple items, use `Choice("foo", checked=True)` instead.
+                 multiple items, use ``Choice("foo", checked=True)`` instead.
 
         validate: Require the entered value to pass a validation. The
                   value can not be submitted until the validator accepts
                   it (e.g. to check minimum password length).
 
                   This should be a function accepting the input and
-                  returning a boolean. An optional second return value
-                  is the error message to display.
+                  returning a boolean. Alternatively, the return value
+                  may be a string (indicating failure), which contains
+                  the error message to be displayed.
 
         qmark: Question prefix displayed in front of the question.
-               By default this is a `?`
+               By default this is a ``?``.
 
         style: A custom color and style for the question parts. You can
                configure colors as well as font types for different elements.
@@ -61,7 +80,7 @@ def checkbox(
                         to initially set the pointer position to.
 
     Returns:
-        Question: Question instance, ready to be prompted (using `.ask()`).
+        :class:`Question`: Question instance, ready to be prompted (using ``.ask()``).
     """
 
     merged_style = merge_styles(
@@ -91,7 +110,7 @@ def checkbox(
         if ic.is_answered:
             nbr_selected = len(ic.selected_options)
             if nbr_selected == 0:
-                tokens.append(("class:answer", " done"))
+                tokens.append(("class:answer", "done"))
             elif nbr_selected == 1:
                 if isinstance(ic.get_selected_values()[0].title, list):
                     ts = ic.get_selected_values()[0].title
@@ -105,18 +124,18 @@ def checkbox(
                     tokens.append(
                         (
                             "class:answer",
-                            " [{}]".format(ic.get_selected_values()[0].title),
+                            "[{}]".format(ic.get_selected_values()[0].title),
                         )
                     )
             else:
                 tokens.append(
-                    ("class:answer", " done ({} selections)".format(nbr_selected))
+                    ("class:answer", "done ({} selections)".format(nbr_selected))
                 )
         else:
             tokens.append(
                 (
                     "class:instruction",
-                    " (Use arrow keys to move, "
+                    "(Use arrow keys to move, "
                     "<space> to select, "
                     "<a> to toggle, "
                     "<i> to invert)",
@@ -130,19 +149,15 @@ def checkbox(
     def perform_validation(selected_values: List[str]) -> bool:
 
         verdict = validate(selected_values)
+        valid = verdict is True
 
-        if isinstance(verdict, bool):
-            valid = verdict
-            error_message = FormattedText(
-                [("class:validation-toolbar", "Invalid selection")]
-            )
-        else:
-            valid, error_message = verdict
+        if not valid:
+            if verdict is False:
+                error_text = INVALID_INPUT
+            else:
+                error_text = str(verdict)
 
-            if isinstance(error_message, str):
-                error_message = FormattedText(
-                    [("class:validation-toolbar", error_message)]
-                )
+            error_message = FormattedText([("class:validation-toolbar", error_text)])
 
         ic.error_message = (
             error_message if not valid and ic.submission_attempted else None
