@@ -17,6 +17,7 @@ from questionary.constants import (
     SELECTED_POINTER,
     INDICATOR_SELECTED,
     INDICATOR_UNSELECTED,
+    INVALID_INPUT,
 )
 
 # This is a cut-down version of `prompt_toolkit.formatted_text.AnyFormattedText`
@@ -29,14 +30,37 @@ FormattedText = Union[
 ]
 
 
-class Choice(object):
-    """One choice in a select, rawselect or checkbox."""
+class Choice:
+    """One choice in a :meth:`select`, :meth:`rawselect` or :meth:`checkbox`.
+
+    Args:
+        title: Text shown in the selection list.
+
+        value: Value returned, when the choice is selected.
+
+        disabled: If set, the choice can not be selected by the user. The
+                  provided text is used to explain, why the selection is
+                  disabled.
+
+        checked: Preselect this choice when displaying the options.
+
+        shortcut_key: Key shortcut used to select this item.
+    """
 
     title: FormattedText
+    """Dispay string for the choice"""
+
     value: Optional[Any]
+    """Value of the choice"""
+
     disabled: Optional[str]
+    """Whether the choice can be selected"""
+
     checked: Optional[bool]
+    """Whether the choice is initially selected"""
+
     shortcut_key: Optional[str]
+    """A shortcut key for the choice"""
 
     def __init__(
         self,
@@ -46,21 +70,6 @@ class Choice(object):
         checked: Optional[bool] = False,
         shortcut_key: Optional[str] = None,
     ) -> None:
-        """Create a new choice.
-
-        Args:
-            title: Text shown in the selection list.
-
-            value: Value returned, when the choice is selected.
-
-            disabled: If set, the choice can not be selected by the user. The
-                      provided text is used to explain, why the selection is
-                      disabled.
-
-            checked: Preselect this choice when displaying the options.
-
-            shortcut_key: Key shortcut used to select this item.
-        """
 
         self.disabled = disabled
         self.title = title
@@ -80,7 +89,16 @@ class Choice(object):
 
     @staticmethod
     def build(c: Union[str, "Choice", Dict[str, Any]]) -> "Choice":
-        """Create a choice object from different representations."""
+        """Create a choice object from different representations.
+
+        Args:
+            c: Either a :obj:`str`, :class:`Choice` or :obj:`dict` with
+               ``name``, ``value``, ``disabled``, ``checked`` and
+               ``key`` properties.
+
+        Returns:
+            An instance of the :class:`Choice` object.
+        """
 
         if isinstance(c, Choice):
             return c
@@ -100,13 +118,16 @@ class Separator(Choice):
     """Used to space/separate choices group."""
 
     default_separator: str = "-" * 15
+    """The default seperator used if none is specified"""
+
     line: str
+    """The string being used as a seperator"""
 
     def __init__(self, line: Optional[str] = None) -> None:
         """Create a separator in a list.
 
         Args:
-            line: Text to be displayed in the list, by default uses `---`.
+            line: Text to be displayed in the list, by default uses ``---``.
         """
 
         self.line = line or self.default_separator
@@ -410,7 +431,7 @@ def build_validator(validate: Any) -> Optional[Validator]:
                     verdict = validate(document.text)
                     if verdict is not True:
                         if verdict is False:
-                            verdict = "invalid input"
+                            verdict = INVALID_INPUT
                         raise ValidationError(
                             message=verdict, cursor_position=len(document.text)
                         )
@@ -467,13 +488,22 @@ def create_inquirer_layout(
 def print_formatted_text(text: str, style: Optional[str] = None, **kwargs: Any) -> None:
     """Print formatted text.
 
-    Args:
-        text: text to be printed
-        style: style used for printing. uses as prompt toolkit style string, details at
-            https://python-prompt-toolkit.readthedocs.io/en/master/pages/advanced_topics/styling.html#style-strings
+    Sometimes you want to spice up your printed messages a bit,
+    :meth:`questionary.print` is a helper to do just that.
 
     Example:
-        print_formatted_text("Hello World!", style="bold italic fg:darkred")"""
+
+        >>> import questionary
+        >>> questionary.print("Hello World 🦄", style="bold italic fg:darkred")
+        Hello World 🦄
+
+    .. image:: ../images/print.gif
+
+    Args:
+        text: Text to be printed.
+        style: Style used for printing. The style argument uses the
+            prompt :ref:`toolkit style strings <prompt_toolkit:styling>`.
+    """
     from prompt_toolkit import print_formatted_text as pt_print
     from prompt_toolkit.formatted_text import FormattedText as FText
 
