@@ -21,33 +21,50 @@ def confirm(
     default: bool = True,
     qmark: str = DEFAULT_QUESTION_PREFIX,
     style: Optional[Style] = None,
+    auto_enter: bool = True,
     **kwargs: Any,
 ) -> Question:
-    """Prompt the user to confirm or reject.
+    """A yes or no question. The user can either confirm or deny.
 
     This question type can be used to prompt the user for a confirmation
     of a yes-or-no question. If the user just hits enter, the default
     value will be returned.
 
+    Example:
+        >>> import questionary
+        >>> questionary.confirm("Are you amazed?").ask()
+        ? Are you amazed? Yes
+        True
+
+    .. image:: ../images/confirm.gif
+
+    This is just a realy basic example, the prompt can be customised using the
+    parameters.
+
+
     Args:
-        message: Question text
+        message: Question text.
 
         default: Default value will be returned if the user just hits
                  enter.
 
         qmark: Question prefix displayed in front of the question.
-               By default this is a `?`
+               By default this is a ``?``.
 
         style: A custom color and style for the question parts. You can
                configure colors as well as font types for different elements.
 
+        auto_enter: If set to `False`, the user needs to press the 'enter' key to
+            accept their answer. If set to `True`, a valid input will be
+            accepted without the need to press 'Enter'.
+
     Returns:
-        Question: Question instance, ready to be prompted (using `.ask()`).
+        :class:`Question`: Question instance, ready to be prompted (using `.ask()`).
     """
 
     merged_style = merge_styles([DEFAULT_STYLE, style])
 
-    status = {"answer": None}
+    status = {"answer": None, "complete": False}
 
     def get_prompt_tokens():
         tokens = []
@@ -55,15 +72,20 @@ def confirm(
         tokens.append(("class:qmark", qmark))
         tokens.append(("class:question", " {} ".format(message)))
 
+        if not status["complete"]:
+            instruction = YES_OR_NO if default else NO_OR_YES
+            tokens.append(("class:instruction", "{} ".format(instruction)))
+
         if status["answer"] is not None:
-            answer = " {}".format(YES if status["answer"] else NO)
+            answer = YES if status["answer"] else NO
             tokens.append(("class:answer", answer))
-        else:
-            instruction = " {}".format(YES_OR_NO if default else NO_OR_YES)
-            tokens.append(("class:instruction", instruction))
 
         return to_formatted_text(tokens)
 
+    def exit_with_result(event):
+        status["complete"] = True
+        event.app.exit(result=status["answer"])
+
     bindings = KeyBindings()
 
     @bindings.add(Keys.ControlQ, eager=True)
@@ -75,18 +97,26 @@ def confirm(
     @bindings.add("N")
     def key_n(event):
         status["answer"] = False
-        event.app.exit(result=False)
+        if auto_enter:
+            exit_with_result(event)
 
     @bindings.add("y")
     @bindings.add("Y")
     def key_y(event):
         status["answer"] = True
-        event.app.exit(result=True)
+        if auto_enter:
+            exit_with_result(event)
+
+    @bindings.add(Keys.ControlH)
+    def key_backspace(event):
+        status["answer"] = None
 
     @bindings.add(Keys.ControlM, eager=True)
     def set_answer(event):
-        status["answer"] = default
-        event.app.exit(result=default)
+        if status["answer"] is None:
+            status["answer"] = default
+
+        exit_with_result(event)
 
     @bindings.add(Keys.Any)
     def other(event):
