@@ -20,24 +20,41 @@ def rawselect(
 
     The user can only select one option.
 
-    Args:
-        message: Question text
+    Example:
+        >>> import questionary
+        >>> questionary.rawselect(
+        ...     "What do you want to do?",
+        ...     choices=[
+        ...         "Order a pizza",
+        ...         "Make a reservation",
+        ...         "Ask for opening hours"
+        ...     ]).ask()
+        ? What do you want to do? Order a pizza
+        'Order a pizza'
 
-        choices: Items shown in the selection, this can contain `Choice` or
-                 or `Separator` objects or simple items as strings. Passing
-                 `Choice` objects, allows you to configure the item more
-                 (e.g. preselecting it or disabeling it).
+    .. image:: ../images/rawselect.gif
+
+    This is just a realy basic example, the prompt can be customised using the
+    parameters.
+
+    Args:
+        message: Question text.
+
+        choices: Items shown in the selection, this can contain :class:`Choice` or
+                 or :class:`Separator` objects or simple items as strings. Passing
+                 :class:`Choice` objects, allows you to configure the item more
+                 (e.g. preselecting it or disabling it).
 
         default: Default return value (single value).
 
         qmark: Question prefix displayed in front of the question.
-               By default this is a `?`
+               By default this is a ``?``.
 
         style: A custom color and style for the question parts. You can
                configure colors as well as font types for different elements.
 
     Returns:
-        Question: Question instance, ready to be prompted (using `.ask()`).
+        :class:`Question`: Question instance, ready to be prompted (using ``.ask()``).
     """
     return select.select(
         message,
